==> jc-1.4.0.tar.gz: soot/util/LargeNumberedMap.h <==
// public final class soot.util.LargeNumberedMap

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 58232727256dfda3 soot_util_LargeNumberedMap

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_LargeNumberedMap_H_
#define _JC_soot_util_LargeNumberedMap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_Numberable$object;
struct _jc_soot_util_Numberer$object;

// Typedefs
typedef struct _jc_soot_util_LargeNumberedMap$sub_refs	_jc_soot_util_LargeNumberedMap$sub_refs;
typedef struct _jc_soot_util_LargeNumberedMap$sub_nonrefs	_jc_soot_util_LargeNumberedMap$sub_nonrefs;
typedef struct _jc_soot_util_LargeNumberedMap$refs	_jc_soot_util_LargeNumberedMap$refs;
typedef struct _jc_soot_util_LargeNumberedMap$nonrefs	_jc_soot_util_LargeNumberedMap$nonrefs;
typedef struct _jc_soot_util_LargeNumberedMap$object	_jc_soot_util_LargeNumberedMap$object;

typedef const struct _jc_soot_util_LargeNumberedMap$vmethods	_jc_soot_util_LargeNumberedMap$vmethods;
typedef const struct _jc_soot_util_LargeNumberedMap$vtable	_jc_soot_util_LargeNumberedMap$vtable;
typedef const struct _jc_soot_util_LargeNumberedMap$vtype	_jc_soot_util_LargeNumberedMap$vtype;

// Constructors
extern void _jc_soot_util_LargeNumberedMap$method$_init$8c7097b88cd3615e(_jc_env *, struct _jc_soot_util_LargeNumberedMap$object *, struct _jc_soot_util_Numberer$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_util_LargeNumberedMap$method$get$c5be1ff646e25056(_jc_env *, struct _jc_soot_util_LargeNumberedMap$object *, struct _jc_object *);
extern jboolean _jc_soot_util_LargeNumberedMap$method$put$4775e23bd8948d4f(_jc_env *, struct _jc_soot_util_LargeNumberedMap$object *, struct _jc_object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_LargeNumberedMap$method_info$get$c5be1ff646e25056;
extern _jc_method _jc_soot_util_LargeNumberedMap$method_info$put$4775e23bd8948d4f;

// Virtual methods structure
struct _jc_soot_util_LargeNumberedMap$vmethods {
	struct _jc_java_lang_Object$object	*(*get$c5be1ff646e25056)(_jc_env *, struct _jc_soot_util_LargeNumberedMap$object *, struct _jc_object *);
	jboolean	(*put$4775e23bd8948d4f)(_jc_env *, struct _jc_soot_util_LargeNumberedMap$object *, struct _jc_object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_util_LargeNumberedMap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_LargeNumberedMap$vmethods	soot_util_LargeNumberedMap;
};

// Vtype
struct _jc_soot_util_LargeNumberedMap$vtype {
	_jc_type			type;
	_jc_soot_util_LargeNumberedMap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_LargeNumberedMap$sub_refs {
	_jc_object_array	*values;
	_jc_long_array	*bits;
	struct _jc_soot_util_Numberer$object	*universe;
};

// Reference instance fields (object)
struct _jc_soot_util_LargeNumberedMap$refs {
    _jc_soot_util_LargeNumberedMap$sub_refs	soot_util_LargeNumberedMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_LargeNumberedMap$sub_nonrefs {
	jint	size;
};

// Non-reference instance fields (object)
struct _jc_soot_util_LargeNumberedMap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_LargeNumberedMap$sub_nonrefs	soot_util_LargeNumberedMap;
};

// Object instance structure
struct _jc_soot_util_LargeNumberedMap$object {
	_jc_soot_util_LargeNumberedMap$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_LargeNumberedMap$vtype	*vtype;
	_jc_soot_util_LargeNumberedMap$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_LargeNumberedMap$vtype _jc_soot_util_LargeNumberedMap$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_LargeNumberedMap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_LargeNumberedMap$class_object;

#endif	/* _JC_soot_util_LargeNumberedMap_H_ */

==> jc-1.4.6.tar.gz: soot/util/LargeNumberedMap.h <==
// public final class soot.util.LargeNumberedMap

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 58232727256dfda3 soot_util_LargeNumberedMap

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_LargeNumberedMap_H_
#define _JC_soot_util_LargeNumberedMap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_Numberable$object;
struct _jc_soot_util_Numberer$object;

// Typedefs
typedef struct _jc_soot_util_LargeNumberedMap$sub_refs	_jc_soot_util_LargeNumberedMap$sub_refs;
typedef struct _jc_soot_util_LargeNumberedMap$sub_nonrefs	_jc_soot_util_LargeNumberedMap$sub_nonrefs;
typedef struct _jc_soot_util_LargeNumberedMap$refs	_jc_soot_util_LargeNumberedMap$refs;
typedef struct _jc_soot_util_LargeNumberedMap$nonrefs	_jc_soot_util_LargeNumberedMap$nonrefs;
typedef struct _jc_soot_util_LargeNumberedMap$object	_jc_soot_util_LargeNumberedMap$object;

typedef const struct _jc_soot_util_LargeNumberedMap$vmethods	_jc_soot_util_LargeNumberedMap$vmethods;
typedef const struct _jc_soot_util_LargeNumberedMap$vtable	_jc_soot_util_LargeNumberedMap$vtable;
typedef const struct _jc_soot_util_LargeNumberedMap$vtype	_jc_soot_util_LargeNumberedMap$vtype;

// Constructors
extern void _jc_soot_util_LargeNumberedMap$method$_init$8c7097b88cd3615e(_jc_env *, struct _jc_soot_util_LargeNumberedMap$object *, struct _jc_soot_util_Numberer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_util_LargeNumberedMap$method$get$c5be1ff646e25056(_jc_env *, struct _jc_soot_util_LargeNumberedMap$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_util_LargeNumberedMap$method$put$4775e23bd8948d4f(_jc_env *, struct _jc_soot_util_LargeNumberedMap$object *, struct _jc_object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_LargeNumberedMap$method_info$get$c5be1ff646e25056;
extern _jc_method _jc_soot_util_LargeNumberedMap$method_info$put$4775e23bd8948d4f;

// Virtual methods structure
struct _jc_soot_util_LargeNumberedMap$vmethods {
	struct _jc_java_lang_Object$object	*(*get$c5be1ff646e25056)(_jc_env *, struct _jc_soot_util_LargeNumberedMap$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*put$4775e23bd8948d4f)(_jc_env *, struct _jc_soot_util_LargeNumberedMap$object *, struct _jc_object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_LargeNumberedMap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_LargeNumberedMap$vmethods	soot_util_LargeNumberedMap;
};

// Vtype
struct _jc_soot_util_LargeNumberedMap$vtype {
	_jc_type			type;
	_jc_soot_util_LargeNumberedMap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_LargeNumberedMap$sub_refs {
	_jc_object_array	*values;
	_jc_long_array	*bits;
	struct _jc_soot_util_Numberer$object	*universe;
};

// Reference instance fields (object)
struct _jc_soot_util_LargeNumberedMap$refs {
    _jc_soot_util_LargeNumberedMap$sub_refs	soot_util_LargeNumberedMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_LargeNumberedMap$sub_nonrefs {
	jint	size;
};

// Non-reference instance fields (object)
struct _jc_soot_util_LargeNumberedMap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_LargeNumberedMap$sub_nonrefs	soot_util_LargeNumberedMap;
};

// Object instance structure
struct _jc_soot_util_LargeNumberedMap$object {
	_jc_soot_util_LargeNumberedMap$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_LargeNumberedMap$vtype	*vtype;
	_jc_soot_util_LargeNumberedMap$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_LargeNumberedMap$vtype _jc_soot_util_LargeNumberedMap$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_LargeNumberedMap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_LargeNumberedMap$class_object;

#endif	/* _JC_soot_util_LargeNumberedMap_H_ */
